import 'package:http/http.dart';
import 'package:rec_api_dart/rec_api_dart.dart';

class ProductsService extends ServiceBase {
  ProductsService({required EnvBase env, Client? client})
      : super(
          env: env,
          client: client,
          interceptors: [UserTokenInterceptor()],
        );

  /// List all [Product]s for the authenticated user
  Future<ApiListResponse<Product>> list({String? status}) {
    final uri = ApiPaths.searchProducts.withQueryParams({
      'limit': '100',
      if (status != null) 'status': status,
    }).asUri(env.API_URL);

    return this.get(uri).then(_mapProducts);
  }

  ApiListResponse<Product> _mapProducts(
    Map<String, dynamic> data,
  ) {
    return ApiListResponse.fromJson(
      data['data'],
      mapper: (el) => Product.fromJson(el),
    );
  }
}
